<template>
    <div class="app-container">
        <el-form :model="queryParams" ref="queryForm" size="small" :inline="true" v-show="showSearch" label-width="68px">
            <el-form-item label="单位缴费流水" prop="serialNumber">
                <el-input v-model="queryParams.serialNumber" placeholder="请输入单位缴费流水" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="发票号" prop="invoiceNo">
                <el-input v-model="queryParams.invoiceNo" placeholder="请输入发票号" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="是否开发票" prop="isInvoice">
                <el-input v-model="queryParams.isInvoice" placeholder="请输入是否开发票" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="应付" prop="copeWith">
                <el-input v-model="queryParams.copeWith" placeholder="请输入应付" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="实付" prop="paidIn">
                <el-input v-model="queryParams.paidIn" placeholder="请输入实付" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="差额" prop="difference">
                <el-input v-model="queryParams.difference" placeholder="请输入差额" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="卡号" prop="cardNo">
                <el-input v-model="queryParams.cardNo" placeholder="请输入卡号" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="团队编号" prop="teamNo">
                <el-input v-model="queryParams.teamNo" placeholder="请输入团队编号" clearable @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item label="否N是Y" prop="isCheckout">
                <el-input v-model="queryParams.isCheckout" placeholder="请输入否N是Y" clearable
                    @keyup.enter.native="handleQuery" />
            </el-form-item>
            <el-form-item>
                <el-button type="primary" icon="el-icon-search" size="mini" @click="handleQuery">搜索</el-button>
                <el-button icon="el-icon-refresh" size="mini" @click="resetQuery">重置</el-button>
            </el-form-item>
        </el-form>

        <el-row :gutter="10" class="mb8">
            <el-col :span="1.5">
                <el-button type="primary" plain icon="el-icon-plus" size="mini" @click="handleAdd"
                    v-hasPermi="['system:pay:add']">新增
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="success" plain icon="el-icon-edit" size="mini" :disabled="single" @click="handleUpdate"
                    v-hasPermi="['system:pay:edit']">修改
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="danger" plain icon="el-icon-delete" size="mini" :disabled="multiple" @click="handleDelete"
                    v-hasPermi="['system:pay:remove']">删除
                </el-button>
            </el-col>
            <el-col :span="1.5">
                <el-button type="warning" plain icon="el-icon-download" size="mini" @click="handleExport"
                    v-hasPermi="['system:pay:export']">导出
                </el-button>
            </el-col>
            <right-toolbar :showSearch.sync="showSearch" @queryTable="getList"></right-toolbar>
        </el-row>

        <el-table v-loading="loading" :data="payList" @selection-change="handleSelectionChange">
            <el-table-column type="selection" width="55" align="center" />
            <el-table-column label="单位id" align="center" prop="compId" />
            <el-table-column label="单位缴费流水" align="center" prop="serialNumber" />
            <el-table-column label="发票号" align="center" prop="invoiceNo" />
            <el-table-column label="是否开发票" align="center" prop="isInvoice">
                <template slot-scope="scope">
                    <dict-tag :options="dict.type.sys_yes_no" :value="scope.row.isInvoice" />
                </template>
            </el-table-column>
            <el-table-column label="应付" align="center" prop="copeWith" />
            <el-table-column label="实付" align="center" prop="paidIn" />
            <el-table-column label="差额" align="center" prop="difference" />
            <el-table-column label="卡号" align="center" prop="cardNo" />
            <el-table-column label="团队编号" align="center" prop="teamNo" />
            <el-table-column label="否N是Y" align="center" prop="isCheckout">
                <template slot-scope="scope">
                    <dict-tag :options="dict.type.sys_yes_no" :value="scope.row.isCheckout" />
                </template>
            </el-table-column>
            <el-table-column label="操作" align="center" class-name="small-padding fixed-width">
                <template slot-scope="scope">
                    <el-button size="mini" type="text" icon="el-icon-edit" @click="handleUpdate(scope.row)"
                        v-hasPermi="['system:pay:edit']">修改
                    </el-button>
                    <el-button size="mini" type="text" icon="el-icon-delete" @click="handleDelete(scope.row)"
                        v-hasPermi="['system:pay:remove']">删除
                    </el-button>
                </template>
            </el-table-column>
        </el-table>

        <pagination v-show="total > 0" :total="total" :page.sync="queryParams.pageNum" :limit.sync="queryParams.pageSize"
            @pagination="getList" />

        <!-- 添加或修改体检单位缴费主对话框 -->
        <el-dialog :title="title" :visible.sync="open" width="500px" append-to-body>
            <el-form ref="form" :model="form" :rules="rules" label-width="80px">
                <el-form-item label="应付" prop="copeWith">
                    <el-input v-model="form.copeWith" placeholder="请输入应付" />
                </el-form-item>
                <el-form-item label="实付" prop="paidIn">
                    <el-input v-model="form.paidIn" placeholder="请输入实付" />
                </el-form-item>
                <el-form-item label="卡号" prop="cardNo">
                    <el-input v-model="form.cardNo" placeholder="请输入卡号" />
                </el-form-item>
            </el-form>
            <div slot="footer" class="dialog-footer">
                <el-button type="primary" @click="submitForm">确 定</el-button>
                <el-button @click="cancel">取 消</el-button>
            </div>
        </el-dialog>
    </div>
</template>

<script>
import {
    listPay,
    getPay,
    delPay,
    addPay,
    updatePay
} from "@/api/system/pay";

export default {
    name: "Pay",
    data() {
        let checkPhoneNum = (rule, value, callback) => {
         console.log( value)
      let patter = new RegExp(/^1\s*[3456789]\s*(\d\s*){9}$/);
      if (value == "" && value == undefined && !value) {
        return callback('');
      }  else if(value != undefined && value != ""){
        return callback();
      }else if (!patter.test(value)) {
        return callback('');
      }
    };
        return {
            // 遮罩层
            loading: true,
            // 选中数组
            ids: [],
            // 非单个禁用
            single: true,
            // 非多个禁用
            multiple: true,
            // 显示搜索条件
            showSearch: true,
            // 总条数
            total: 0,
            // 体检单位缴费主表格数据
            payList: [],
            // 弹出层标题
            title: "",
            // 是否显示弹出层
            open: false,
            // 查询参数
            queryParams: {
                pageNum: 1,
                pageSize: 10,
                compId: null,
                serialNumber: null,
                invoiceNo: null,
                isInvoice: null,
                copeWith: null,
                paidIn: null,
                difference: null,
                cardNo: null,
                teamNo: null,
                isCheckout: null
            },
            // 表单参数
            form: {},
            // 表单校验
            rules: {
                isCheckout: [
                    {
                        required: true, validator: checkPhoneNum,  trigger: "blur"
                    }
                ]
            }
        };
    },
    created() {
        this.getList();
    },
    methods: {
        /** 查询体检单位缴费主列表 */
        getList() {
            this.loading = true;
            listPay(this.queryParams).then(response => {
                this.payList = response.rows;
                this.total = response.total;
                this.loading = false;
            });
        },
        // 取消按钮
        cancel() {
            this.open = false;
            this.reset();
        },
        // 表单重置
        reset() {
            this.form = {
                id: null,
                compId: null,
                serialNumber: null,
                invoiceNo: null,
                isInvoice: null,
                copeWith: null,
                paidIn: null,
                difference: null,
                cardNo: null,
                teamNo: null,
                createTime: null,
                createBy: null,
                updateTime: null,
                updateBy: null,
                deleted: null,
                isCheckout: null
            };
            this.resetForm("form");
        },
        /** 搜索按钮操作 */
        handleQuery() {
            this.queryParams.pageNum = 1;
            this.getList();
        },
        /** 重置按钮操作 */
        resetQuery() {
            this.resetForm("queryForm");
            this.handleQuery();
        },
        // 多选框选中数据
        handleSelectionChange(selection) {
            this.ids = selection.map(item => item.id)
            this.single = selection.length !== 1
            this.multiple = !selection.length
        },
        /** 新增按钮操作 */
        handleAdd() {
            this.reset();
            this.open = true;
            this.title = "添加体检单位缴费主";
        },
        /** 修改按钮操作 */
        handleUpdate(row) {
            this.reset();
            const id = row.id || this.ids
            getPay(id).then(response => {
                this.form = response.data;
                this.open = true;
                this.title = "修改体检单位缴费主";
            });
        },
        /** 提交按钮 */
        submitForm() {

        },
        /** 删除按钮操作 */
        handleDelete(row) {



        },

        /** 复选框选中数据 */

        SelectionChange(selection) {

        }
        ,

        /** 导出按钮操作 */
        handleExport() {

        }
    }
}
    ;
</script>
